@@ -3,7 +3,7 @@ from django.forms import (Form, ModelForm, BaseModelForm, model_to_dict,
                           DEFAULT_DATE_INPUT_FORMATS,
                           DEFAULT_TIME_INPUT_FORMATS,
                           DEFAULT_DATETIME_INPUT_FORMATS,
-                          Media, MediaDefiningClass
+                          Media, MediaDefiningClass)
 
 # Import SelectDateWidget from extras
 from django.forms.extras import SelectDateWidget
