@@ -1,16 +1,20 @@
 from django import forms
 
 from floppyforms.widgets import (TextInput, HiddenInput, CheckboxInput, Select,
-                                 FileInput, ClearableFileInput, SelectMultiple,
+                                 ClearableFileInput, SelectMultiple,
                                  DateInput, DateTimeInput, TimeInput, URLInput,
-                                 NumberInput, RangeInput, EmailInput,
-                                 NullBooleanSelect, SlugInput, IPAddressInput)
+                                 NumberInput, EmailInput, NullBooleanSelect,
+                                 SlugInput, IPAddressInput,
+                                 SplitDateTimeWidget,
+                                 SplitHiddenDateTimeWidget)
 
 __all__ = (
     'Field', 'CharField', 'IntegerField', 'DateField', 'TimeField',
     'DateTimeField', 'EmailField', 'FileField', 'ImageField', 'URLField',
     'BooleanField', 'NullBooleanField', 'ChoiceField', 'MultipleChoiceField',
     'FloatField', 'DecimalField', 'SlugField', 'RegexField', 'IPAddressField',
+    'TypedChoiceField', 'FilePathField', 'TypedMultipleChoiceField',
+    'ComboField', 'MultiValueField', 'SplitDateTimeField',
 )
 
 
@@ -25,7 +29,7 @@ class Field(forms.Field):
                                                  # Django < 1.3
 
 
-class CharField(Field):
+class CharField(Field, forms.CharField):
     widget = TextInput
 
 
@@ -41,6 +45,14 @@ class ChoiceField(Field, forms.ChoiceField):
     widget = Select
 
 
+class TypedChoiceField(ChoiceField, forms.TypedChoiceField):
+    widget = Select
+
+
+class FilePathField(ChoiceField, forms.FilePathField):
+    widget = Select
+
+
 class FileField(Field, forms.FileField):
     widget = ClearableFileInput
 
@@ -53,6 +65,21 @@ class MultipleChoiceField(forms.MultipleChoiceField):
     widget = SelectMultiple
 
 
+try:
+    Parent = forms.TypedMultipleChoiceField
+except AttributeError:  # Django < 1.3
+    class Parent(forms.MultipleChoiceField):
+        """No-op class for older Django versions"""
+        def __init__(self, *args, **kwargs):
+            kwargs.pop('coerce', None)
+            kwargs.pop('empty_value', None)
+            super(Parent, self).__init__(*args, **kwargs)
+
+
+class TypedMultipleChoiceField(MultipleChoiceField, Parent):
+    pass
+
+
 class DateField(Field, forms.DateField):
     widget = DateInput
 
@@ -107,3 +134,21 @@ class RegexField(Field, forms.RegexField):
 
 class IPAddressField(Field, forms.IPAddressField):
     widget = IPAddressInput
+
+
+class ComboField(Field, forms.ComboField):
+    pass
+
+
+class MultiValueField(Field, forms.MultiValueField):
+    pass
+
+
+class SplitDateTimeField(forms.SplitDateTimeField):
+    widget = SplitDateTimeWidget
+    hidden_widget = SplitHiddenDateTimeWidget
+
+    def __init__(self, *args, **kwargs):
+        super(SplitDateTimeField, self).__init__(*args, **kwargs)
+        for widget in self.widget.widgets:
+            widget.is_required = self.required
